      DOUBLE PRECISION FUNCTION HF2002_IERS (TJD)
*+
*  - - - - - - - - - - - -  
*   H F 2 0 0 2 _ I E R S
*  - - - - - - - - - - - - 
*
*  This routine is part of the International Earth Rotation and
*  Reference Systems Service (IERS) Conventions software collection.
*
*  This function computes TCB-TCG at the geocenter using an approximation of the 
*  time ephemeris TE405.  It approximates TE405 (including the trend) with errors
*  of 0.453 ns (RMS) and 2.248 ns (maximum) for the period 1600-2200 (Note 1).
* 
*  In general, Class 1, 2, and 3 models represent physical effects that
*  act on geodetic parameters while canonical models provide lower-level
*  representations or basic computations that are used by Class 1, 2, or
*  3 models.
* 
*  Status: Class 1 model
*
*     Class 1 models are those recommended to be used a priori in the
*     reduction of raw space geodetic data in order to determine
*     geodetic parameter estimates.
*     Class 2 models are those that eliminate an observational
*     singularity and are purely conventional in nature.
*     Class 3 models are those that are not required as either Class
*     1 or 2.
*     Canonical models are accepted as is and cannot be classified as a
*     Class 1, 2, or 3 model.
*
*  Given:
*     tjd          d      Julian date in days (Note 1)
*
*  Returned:
*     hf2002_iers  d      TCB-TCG in seconds
*
*  Notes:
*
*  1) Although the Julian date is, formally, barycentric dynamical time (TDB),
*     the terrestrial dynamical time (TT) can be used with no practical
*     effect on the accuracy of the prediction. 
*
*  2) An offset of '0.3960 ns' remains at the epoch JD = 2443144.5003725.
*
*  Called:
*     None
*
*  Test case:
*     given input: tjd = 2341970.0D0
*     
*     expected output: hf2002_iers = -129.4460764716997D0 seconds 
*
*  References:
*
*     Harada, W. and Fukushima, T., 2003, ``Harmonic decomposition of 
*     time ephemeris TE405", Astron. J., 126, pp. 2557-2561
*
*     Petit, G. and Luzum, B. (eds.), IERS Conventions (2010),
*     IERS Technical Note No. 36, BKG (2010)
*
*  Revisions:
*  2009 August 28 B.E.Stetzler  Initial standardization of function
*                               and provided a test case 
*  2009 August 28 B.E.Stetzler  Capitalized all variables for FORTRAN
*                               77 compatibility
*  2009 August 31 B.E.Stetzler  Provided a test case
*  2010 June   22 B.E.Stetzler  Added linear correction to function
*                               hf2002 and updated test case
*  2010 June   23 B.E.Stetzler  Changed function name to hf2002_iers
*                               to distinguish it from original
*  2010 August 13 B.E.Stetzler  Added SAVE statement, provided the HF2002
*                               model coefficients as DATA blocks
*  2010 August 26 B.E.Stetzler  Negated use of external data file by
*                               placing all data in DATA statements
*                               and updated test case
*-----------------------------------------------------------------------
      IMPLICIT NONE

      SAVE

*------------------------
*  D E F I N I T I O N S
*------------------------
*  ne: number of Fourier (=sin,cos) terms
*  nx: number of mixed secular (=t*sin,t*cos) terms
*  hf2002(1,j): coefficient of sin or t*sin
*  hf2002(2,j): coefficient of cos or t*cos
*  hf2002(3,j): frequency of sin/cos or t*sin/t*cos terms

      DOUBLE PRECISION TJD

      INTEGER N, NE, NX, NA
      PARAMETER(N = 73000, NE = 463, NX = 36, NA = NE+NX+1)

      INTEGER I,J
      DOUBLE PRECISION OFFSET,T_START,PI2,CN1DT
      DOUBLE PRECISION T,PI2T,XI,S0,S1,S2,ARG,CNDTI

*
*  ===========================
*  Harada and Fukushima model
*  ===========================
*
*  499 sets of three coefficients. 463 Fourier terms and 36 mixed secular
*  terms.
*  Each set is amplitude (microseconds)
*              phase (radians),
*              frequency (radians per Julian millennium since J2000.0).
*
      DOUBLE PRECISION HFDATA(3,500)

      DOUBLE PRECISION LB,C4TERMS,TT0,HF2002
      DATA LB / 1.550519768D-8 /,
     :     C4TERMS / 1.15D-16 /,
     :     TT0 / 2443144.5003725 /
      

*  Fourier terms
      DATA ((HFDATA(I,J),I=1,3),J=  1, 10) /
     :-.3607422901312205D2,   .7004807354556313D2, .1543558517218686D-6,
     : .5050792017742808D-3, -.1551857140652651D-2,.2737736388966212D-2,
     :-.1110866195521218D-4, -.8369721972288442D-5,.5475556880523133D-2,
     : .7124055526623448D-7,  .9136864406672768D-7,.1686160317172538D-4,
     : .1477197271164320D-7,  .3815710887497809D-9,.2283068300762698D-3,
     :-.1439761092555262D-6,  .9892010263573942D-7,.8213394359074665D-2,
     :-.2316662927991430D-6, -.7752736307703353D-7,.3380709739354605D-3,
     :-.5889935994866439D-8,  .1568840788793492D-6,.4783374558389059D-2,
     :-.9289060680123974D-8, -.3126779398827274D-8,.2749068956280150D-2,
     :-.4658794110921387D-8,  .5589192650710019D-8,.3153368978369206D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 11, 20) /
     : .1624221783198742D-7,  .4282874631992123D-9,.1025222715379577D-2,
     :-.4741559256914455D-9, -.6966798283650878D-9,.1413106531097060D-3,
     :-.3717661780051169D-7, -.4182417284491224D-9,.1374619522895021D-2,
     : .4992856894421815D-8,  .4175811659493343D-10,
     : .2324275110041792D-2,
     :-.3927513237953369D-9,  .1109129731589265D-9,.2264946618246240D-2,
     :-.2277808952754580D-6,  .1168285092588522D-5,.2276226527217430D-2,
     : .3702325430790025D-9, -.3860958727917508D-9,.2759367017789291D-2,
     : .5356345285218926D-9, -.2003300206283898D-9,.2541736657062669D-2,
     :-.4224697598657373D-9, -.7980140858065653D-9,.5891489327022314D-2,
     :-.4447468243728452D-9, -.2903711003710961D-9,.6988392539398318D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 21, 30) /
     : .1350117401229672D-6,  .4181242621179520D-6,.3256480775856626D-4,
     : .2486464020852371D-7, -.2257677369323729D-7,.4112474638227115D-2,
     :-.5068537113001582D-8,  .1098138826558983D-8,.4168395174891270D-3,
     : .2532410589020574D-8,  .1159124311424179D-6,.4615545621144005D-3,
     :-.2473234849867198D-8,  .3169445021147717D-8,.3075817659388770D-2,
     : .3151296761335830D-9,  .2443154084302217D-9,.7038513792416362D-3,
     : .3416081970632234D-8, -.2911994996048606D-7,.3112541369498863D-1,
     : .2892522938801448D-9, -.8063727951995007D-11,
     : .2837131903717993D-3,
     :-.1245883947248913D-10, .2735209462793232D-9,.3070757594877823D-2,
     :-.5227517431599800D-8,  .2422640565598737D-7,.5203672159857556D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 31, 40) /
     :-.4581712280905545D-7, -.9098327067664262D-7,.2428451549209403D-2,
     : .5396655865596509D-10,-.1885695032057180D-9,.2853388272606673D-2,
     :-.9022893261729126D-10,-.1987720910933551D-9,.2361683295001627D-2,
     :-.1835588526434671D-7,  .1164172335527893D-7,.6162897315884004D-2,
     : .1009158110373282D-9,  .1871910892928343D-9,.2466336486376989D-2,
     :-.9157742256422147D-7,  .3581228337644414D-7,.1108699635861177D-2,
     :-.9963232394738800D-6, -.7983942708538801D-6,.3425118591597421D-2,
     : .2073310834435524D-4, -.8526527144725272D-5,.2506994396270039D-2,
     :-.3405282971874553D-5, -.3354579673578086D-5,.2307755778736836D-3,
     : .2719829792186439D-5, -.3803777726647080D-5,.2644858375170336D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 41, 50) /
     :-.2294507004726108D-5, .2427636630121663D-6, .9288664877300899D-4,
     :-.1407045780830688D-5,-.6617859401831965D-6, .3386319229007669D-1,
     :-.1052852056871413D-5,-.3687543320435781D-6, .1712559403463366D-2,
     :-.8283476049673876D-7, .5957354831076820D-6, .6873550833216810D-3,
     : .5689340021664698D-6,-.5541153620841981D-6, .5013998985413948D-2,
     : .3323304705630824D-7, .4851030288412512D-6, .2564313487667170D-2,
     : .4177813157776855D-6,-.2662327111186389D-6, .2705214118910913D-2,
     :-.4216884488333074D-6, .1082662331556548D-6, .1734534613922116D-3,
     : .1736229047936550D-6,-.3345344418520158D-6, .2399909090305545D-2,
     : .2924229897807645D-6, .3962867323867327D-6, .1130648471035123D-4/
      DATA ((HFDATA(I,J),I=1,3),J= 51, 60) /
     :-.2678002330198873D-6, .3804930437289855D-6, .2721178183131410D-2,
     :-.1585045296952069D-6, .1720247224005154D-6, .2551951323533716D-2,
     : .2627936128381637D-8,-.2041644037376049D-6, .5244784252116377D-2,
     : .7217814485254228D-7, .1175677386166324D-6, .5137677463496044D-2,
     : .9005409921811831D-7,-.1149734783467991D-6, .3469416047498509D-3,
     : .4357826035069052D-7,-.1105697670906473D-6, .2390860549318159D-2,
     :-.5994960439758268D-7,-.5296752054891529D-7, .2045442683643310D-2,
     : .5677823089402341D-7,-.1040550744150190D-7, .1859018415382242D-3,
     : .5171019079419428D-7,-.5439288656680861D-7, .1282156265726568D-2,
     : .2866545498538825D-7,-.3085150955370329D-7, .6835935036931380D-4/
      DATA ((HFDATA(I,J),I=1,3),J= 61, 70) /
     :-.1788001539479393D-7, .5046417801679899D-7, .7521020606401933D-2,
     : .4788892656062859D-7, .3483685702861919D-8, .9352423208287768D-3,
     : .1711446215864462D-7,-.3897751611510884D-7, .7015483801504634D-1,
     : .1071947761233926D-6, .3947523853961417D-7, .9048039690246687D-4,
     :-.2376933048814591D-7,-.3326590302833507D-7, .5382619551712707D-2,
     : .1781085844515604D-7,-.3818151976024129D-7, .2756867150817492D-3,
     :-.9070117525291347D-8,-.3944791794934784D-7, .6850237713010189D-2,
     :-.2672510512212607D-7, .2485310977603928D-7, .2217400242744592D-2,
     : .2412145243221566D-7, .2167912132615482D-7, .3846468182208301D-2,
     :-.2851277426854771D-7,-.1236155174918225D-7, .3087123599996757D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 71, 80) /
     :-.9075279242542974D-8,-.2847271207862253D-7, .5289690374999808D-2,
     :-.5793158827701244D-7,-.2555696426889860D-7, .2504013388595808D-2,
     : .2239651240558894D-7,-.5824509443683311D-7, .2509993122358184D-2,
     : .8085913130689748D-8, .3762402718800011D-7, .3493097313076993D-3,
     :-.2179308606968244D-7,-.1256585302014376D-7, .7617923270244971D-3,
     :-.1510808493671361D-7,-.1659980001923991D-7, .4552452682123071D-2,
     :-.5303324830103064D-8,-.2204052622550896D-7, .2672644887930448D-2,
     :-.9262526920266113D-8, .1325961281956228D-7, .4450338677411847D-2,
     :-.8181147099714746D-8,-.1926153897993797D-7, .3673010532358748D-2,
     : .1214111949727279D-7,-.1286239832221952D-7, .2968528888316816D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 81, 90) /
     : .9880814270468330D-8,-.9102346829317513D-8, .2459260723700364D-2,
     : .3124783504784345D-7,-.5198673085177134D-8, .2641935840167957D-2,
     :-.8296439705682974D-8,-.1155973409608238D-7, .7751787309872724D-2,
     : .8292806356372127D-8, .1213633084112556D-7, .5883261649270065D-3,
     :-.5476258883120075D-8,-.1319343836892805D-7, .7290229150714889D-2,
     : .5890873632600468D-8, .2962194948926283D-7, .2647939749014787D-2,
     : .2185673264113958D-4,-.2313476788400301D-4, .2738068008204933D-2,
     :-.3027834438225585D-8,-.1155889036553650D-7, .4144511618216058D-3,
     :-.1673492594020654D-8, .1496705720053489D-7, .8562797179322974D-2,
     :-.9035485227597373D-8,-.6821267628697234D-8, .4432702866380613D-4/
      DATA ((HFDATA(I,J),I=1,3),J= 91, 100) /
     : .8644407932252424D-8, .7740737211916836D-8, .2231327774456299D-2,
     : .2175265840532945D-8,-.9918450972701023D-8, .1236209205656727D-3,
     : .1130393813727842D-7, .2577579256083967D-8, .2050435199369926D-2,
     :-.5210721276561770D-9, .1190212930288809D-7, .3499555339624234D-2,
     : .1935269581197157D-7,-.1277887129371821D-7, .1829672963603616D-3,
     :-.3877075266697491D-8, .1020590032108303D-7, .2414512311055326D-3,
     :-.3339073902626760D-8, .7948201165590301D-8, .1455616224046876D-2,
     :-.9127464314553196D-8, .2098547524805985D-8, .6529793098270070D-1,
     : .3801878159769933D-8,-.6339527220726720D-8, .5784697071094618D-4,
     :-.3937076389998502D-8, .7044186440061576D-8, .1378826556391942D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 101, 110) /
     :-.7395163131921652D-8, .3417595939140692D-8, .5825018460511409D-2,
     : .7493475878007402D-8, .2338116608252619D-8, .5302113256434303D-2,
     : .3486137555063446D-8, .8179091610103092D-8, .2726272025936315D-2,
     :-.8286784063047821D-8,-.4426433543871418D-9, .5128631634204823D-2,
     :-.5988781021145016D-8, .3362840551877515D-8, .2911267687878171D-2,
     : .8050366600639101D-9,-.8659139204349855D-8, .6931923099854623D-3,
     : .3218627693116199D-8,-.5994330496822716D-8, .3326103714594801D-2,
     : .2863262094804555D-8,-.5944119915059986D-8, .1027535741722427D-1,
     : .1146978271638669D-8, .6126924486922562D-8, .5196703736850816D-2,
     : .1467060404391516D-7, .1338571178385697D-8, .1021587893376601D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 111, 120) /
     :-.3251945803841642D-9,-.5655974329153575D-8, .1002800583054918D-1,
     : .1240605993820711D-7,-.3128723077185051D-8, .2043971836174905D-2,
     :-.5043456644089333D-8,-.1050967265735785D-8, .2368989262923941D-2,
     : .6033523162324692D-8,-.1869674372701583D-8, .1814675321386244D-2,
     :-.4746725539735345D-8,-.1807341181071009D-8, .2805731447923185D-2,
     : .2667668324067280D-8,-.1098328986543410D-7, .2554850210222714D-2,
     :-.1080822979941600D-8,-.4217796585130676D-8, .5442990459442821D-2,
     : .4680593541259832D-8, .2027474991126809D-8, .4955191434946381D-2,
     : .1398042944568670D-8, .5118215431444166D-8, .2600046444121271D-2,
     :-.1573109756511471D-7, .1736371973586551D-8, .1000842282045475D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 121, 130) /
     :-.4446407788605945D-8,-.6901036841987912D-9, .1870518014425104D-2,
     : .3460132357070674D-9,-.4043953709223549D-8, .2061939100577155D-2,
     : .2330084559122136D-8, .3156177381962272D-8, .5458939415702787D-2,
     :-.7606395474984275D-9,-.2955428754637393D-8, .1015895766055314D0,
     : .5084945249980782D-9,-.3315069356678159D-8, .3963319869330827D-1,
     : .7895371232261695D-10,.3054764491364683D-8, .3629164660666955D-1,
     :-.1456405972454512D-8, .2579614183808809D-8, .3206061726028211D-3,
     : .2749823069140624D-8, .1772197698280038D-9, .4321701839364400D-2,
     : .3043069220536741D-8,-.5064978768433430D-9, .2979261541687699D-2,
     :-.2256065553506145D-8, .2256114199534744D-8, .1198791806521273D-1/
      DATA ((HFDATA(I,J),I=1,3),J= 131, 140) /
     : .7164351969102751D-9, .2500610614060726D-8, .1095112529568389D-1,
     : .2796221341037349D-8, .1560095025018409D-9, .2689352828020606D-2,
     : .8861664726190873D-9,-.5490261812594470D-8, .2462541638112602D-2,
     :-.1164553246104672D-8, .2878136546573441D-8, .5110126886280014D-4,
     :-.2158896990278230D-8,-.1073881165430355D-9, .7483266694573520D-4,
     :-.1973150047771757D-8, .1060410779479770D-8, .2142055123881393D-3,
     : .2868585674863677D-8,-.2031626301108007D-9, .7537522242841582D-2,
     :-.2576150723240583D-8,-.9718319577946839D-9, .7982545197148661D-2,
     : .2183159339042584D-8, .9866320878220946D-9, .7059457235085493D-2,
     : .6591226946394008D-9, .2128048126441316D-8, .2831172913123225D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 141, 150) /
     : .2249166242894215D-8,-.5270092948131695D-9, .7875468358050905D-2,
     :-.2453657920224193D-8,-.5682115495874023D-9, .5009488189134834D-2,
     : .1593764436998005D-8,-.1669010898401346D-8, .3660096941787800D-1,
     : .2479801344300887D-8,-.1624050449174024D-9, .3837929129619078D-4,
     : .1594613012912520D-8, .1505608486414969D-8, .4799763551770145D-2,
     :-.2036892964835858D-8, .6690274230835473D-9, .5064851230964137D-3,
     :-.2805386726409374D-9, .2467932068336509D-8, .2782870119769389D-2,
     :-.5878118451331568D-9,-.2286208197780912D-8, .5018583214432892D-2,
     : .9653637333623212D-9,-.1781042343813382D-8, .6410754708237696D-2,
     : .2241945395485773D-8,-.2814288745275836D-9, .1982252778514077D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 151, 160) /
     :-.1595829315610893D-8, .8539627080862950D-9, .3872010188986099D-1,
     : .1613209394604223D-8, .6589889096542768D-9, .1064464831758375D0,
     : .1495909656020730D-8,-.7165751219780698D-9, .1370047967181062D-1,
     : .5355679701708062D-9,-.1755972924828048D-8, .1629045810761068D-2,
     : .1343559329265783D-8, .1342381135649751D-8, .9797229992036733D-2,
     :-.1491419007162753D-8, .1757869383606540D-8, .2282492704460203D-2,
     : .1716186256421807D-8, .6568677684507776D-9, .4738283698806820D-2,
     : .1893282520648734D-8, .1178995492432753D-8, .1120356967379901D-3,
     :-.2128082467746812D-8, .8028439582029083D-9, .2797278058745660D-3,
     : .9456247612278876D-9,-.1642883875267522D-8, .1363416975892115D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 161, 170) /
     :-.2901818103841213D-8, .3544653114007981D-9, .6380753281342326D-4,
     : .1553402291556393D-8, .6080893877485224D-9, .6839412158307338D-3,
     :-.1178517413057502D-8,-.1451595821895003D-8, .2631657377315557D-2,
     :-.1331005304746146D-8, .8867144784639957D-9, .6237332053147569D-2,
     :-.1390751070252400D-8, .4737273663450358D-9, .2000533393736989D-2,
     : .1410919441691222D-8, .9741944358454778D-9, .1697008479881348D-2,
     :-.1454510264353268D-8,-.2401970384623365D-9, .2396613389730390D-2,
     : .1326450910369529D-8, .4171859254725391D-9, .1025866503249685D-1,
     :-.5009423972784603D-9,-.1313214340898119D-8, .3763021532524492D-2,
     : .8212819967099395D-9, .9725883627067825D-9, .8674038633108266D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 171, 180) /
     : .3925463116481568D-9, .1223881921127894D-8, .4608398137751106D-2,
     : .2228929525821846D-8, .4005120461748033D-10,.2377874736524564D-3,
     :-.9671382248119720D-10,.1247890476082841D-8, .2093459815509765D-2,
     : .1686212608811519D-8,-.6740245388133416D-9, .2269858369549453D-2,
     :-.5974031582196025D-9,-.1288296546181385D-8, .4019907556999726D-2,
     :-.7486232606568761D-9, .1469717544034960D-8, .2587455922421840D-4,
     : .1050488455508379D-8, .1005286287815659D-8, .1191268892047871D-3,
     : .1303612369051311D-8, .3857582454626111D-9, .7934491375472771D-2,
     :-.1253309347993345D-8,-.3441775905083835D-9, .9250157020960863D-2,
     : .7613289282582197D-9, .7898596645489239D-9, .2414364705465891D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 181, 190) /
     :-.1624414164445988D-8, .4807173847215953D-9, .2545848160818224D-2,
     : .1068198761107550D-8, .9742092175805319D-10,.6741706208794401D-1,
     :-.3314886539703506D-10,.1097593104412576D-8, .2701475122915059D-2,
     : .8917546072153177D-9,-.1283971067193269D-9, .6063844697845168D-2,
     : .3574516856128738D-9,-.7452914126187974D-9, .3774610645744299D-2,
     :-.1117234298658721D-8,-.2965246689581362D-9, .5241458288902962D-2,
     :-.6695496565505381D-9,-.5705338384117739D-9, .2186266038051109D-2,
     : .5377209322006719D-9,-.6208815447339500D-9, .6584241720120345D-2,
     :-.2029315864535870D-9,-.1107864179566859D-8, .3082978865031638D-2,
     :-.8128458676568296D-9,-.4846683879249183D-9, .6778954068998573D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 191, 200) /
     :-.9957459596218118D-9, .4163187482636179D-9, .2418406888278559D-2,
     :-.8954832690088770D-9, .1004212699077620D-9, .1541304466868455D-1,
     :-.4379158640908897D-10,-.8581628780416216D-9,.5103608797058886D-2,
     : .2201655227026987D-9, .7734658244682444D-9, .7692899203722514D-2,
     :-.7480850235701969D-9, .1362618947767046D-9, .1037659077318143D-2,
     :-.7558929218588509D-9,-.1305603949184357D-9, .1802666251321689D-2,
     :-.6392242134559192D-9, .9314269830783093D-10,.5166422670894144D-2,
     :-.3405877413670538D-9,-.5942207630498102D-9, .1523593308754680D-2,
     : .3190194715716635D-9, .6266905555436426D-9, .1253498927762283D-1,
     :-.3128251314490901D-9,-.5951654976013094D-9, .6512291346930567D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 201, 210) /
     :  .5434431388771742D-9, .3776875856163035D-9,.1096263720753126D-1,
     :-.6214543448220160D-9,-.3905660228631174D-10,.9587927158089062D-2,
     :  .4493318312736309D-9, .7426542634359477D-9,.4560867773330750D-3,
     :-.6379475705933290D-9,-.2949038420424442D-10,.3637018745489442D-1,
     : .1941447362486384D-10,-.6170877601550803D-9,.4969434836161951D-2,
     :  .5934875222590817D-9,-.1241164554626110D-9,.2838763857768716D-1,
     :  .6292822643974043D-9,-.1761192238396422D-9,.3686060637194409D-3,
     :  .5836531313677895D-9,-.2116081293816702D-9,.4831075611499537D-2,
     : -.3199035589025234D-9,-.5230373446301505D-9,.6256015180329420D-1,
     :  .4213384197698394D-9,-.3866583730378592D-9,.2138509472278212D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 211, 220) /
     : .9148617401342884D-10,-.6012486490565517D-9,.4434875767366729D-2,
     :-.5065924514876447D-9, .9516750884213600D-10,.4876170130786885D-2,
     :-.1671327347664241D-9, .5541742068052495D-9, .1584732425526268D-2,
     : .4742516233618201D-9,-.5279110825066250D-10,.2718258147717910D-3,
     : .4536562201763352D-9,-.3559431417229968D-9, .3143473661581597D-1,
     :-.1256454566421436D-9, .7730151643141527D-9, .2365323077958498D-2,
     : .2537489294253404D-9,-.4566306125060176D-9, .2319868706405841D-2,
     : .5850862679492634D-9, .1868318509923999D-9, .2404184261506247D-2,
     :-.4641281998030454D-9, .2047371331331390D-9, .4507537919827951D-2,
     :-.5036271107574306D-9, .1522297157154102D-9, .8120358967659698D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 221, 230) /
     :-.9797974599628922D-9, .7819960764126175D-9, .2754946334595667D-2,
     :-.4807163656627637D-9, .6230945542347510D-11,.8027327087753101D-2,
     :.4313815098430500D-9, -.6391926294471491D-11,.1328349703109006D-3,
     : .4968803225303094D-9, .1135283239187437D-9, .1712560999585622D-1,
     :.4742989616011725D-9,  .6486879818161514D-10,.4193451907262655D-2,
     : .4072710787444678D-9,-.6403916104015046D-9, .2286451270735826D-2,
     :-.1335189585853065D-9,-.4475588933369106D-9, .5515214988470300D-3,
     : .3627803900114147D-9,-.4736260003866989D-9, .1077261813279066D-3,
     : .3457075943799054D-10,-.5196532297948605D-9,.5410387230879665D-2,
     : .6556522115256526D-10,.4462438527587207D-9, .8900712244492560D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 231, 240) /
     :-.2674802786006308D-9, .3392851103137079D-9, .7346032531159139D-2,
     : .2327783525056712D-9,-.4945374053917901D-9, .2677612715542678D-2,
     :-.4576249395529345D-9,-.9904741706265591D-10,.3199193186911745D-2,
     :-.4016867291141876D-9,-.9864316400626460D-10,.5058350120025396D-2,
     : .2280972821067198D-9, .3230277873185387D-9, .2920344945817200D-2,
     : .3398030349719019D-9, .2291217387948579D-9, .3258092205804068D-2,
     : .3898008999393613D-9,-.2435169915251622D-9, .2714625574596612D-2,
     :-.2130598427449139D-9,-.2942977640100106D-9, .1267520328513516D-1,
     : .3343279712367650D-9,-.1455287580335882D-9, .1975915834449947D-2,
     :-.3792881663596261D-9,.1694135676609154D-11, .9566480673306574D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 241, 250) /
     :-.2928995740623365D-9,-.1608244798969599D-9,.8975083122153608D-2,
     :-.3259161947243498D-9,-.1434113861627583D-9,.7841601816862834D-2,
     :-.2574890137090095D-9,-.2174596169131179D-9,.3096197358781941D-3,
     :-.2438738036287320D-9, .1120440252654530D-9,.2574199208330954D-2,
     :-.2728351883554807D-9,-.1903379250297308D-9,.6725397738200891D-3,
     : .1746804340422424D-9, .3079072079559568D-9,.5023045981273205D-2,
     : .4663557043620813D-9,.2593705709283921D-10,.8244256897362313D-4,
     :-.2905057438261233D-9, .1124290109163225D-9,.6828903527971835D-2,
     : .2240855674718523D-9,-.2395825925769198D-9,.1651223058010825D-3,
     : .2940273962814477D-9, .1870781352134433D-9,.5005333473685890D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 251, 260) /
     :-.2772744943267578D-9,-.9990547807654525D-10,.1230413235990599D-1,
     : .2174799961507276D-9,-.1911194533090434D-9,.7946429436586902D-3,
     : .1947935473525868D-9, .2919975991374098D-9,.8801618350778322D-2,
     :-.2512372292827357D-9,-.1581156692577058D-9,.1883816461738571D-1,
     : .7860533410021359D-10,.3246354641383706D-9,.7866427210081336D-2,
     :-.1164113535271406D-9,-.2964717487141003D-9,.2696735362303725D-2,
     : .2862188142713059D-9, .1267763983099479D-9,.2385469711844272D-2,
     : .2870871600477262D-9,-.8189773946994090D-10,.1378812230220043D0,
     :-.3108945466906160D-9,.9443477409689496D-10,.2666837807084678D-2,
     :-.2464940694539354D-9,.8517280571094190D-10,.1048979325106879D-1/
      DATA ((HFDATA(I,J),I=1,3),J= 261, 270) /
     :-.1876245898129787D-9, .2482838341185015D-9,.5487373860711084D-2,
     : .2497020144147178D-9, .2091601129788077D-9,.1692429173061693D-3,
     : .1064668395721371D-9,-.2504922616545735D-9,.2826420554431669D-2,
     :-.2012267833816614D-9,-.1204681104085186D-9,.2448701670501302D-2,
     : .1968990731276268D-9, .1783891360037828D-9,.7289260832630369D-1,
     :-.2001065682597281D-9, .1777762404612535D-9,.4091812816884239D-2,
     :-.2459637614332227D-9, .7526421818448215D-10,.9227785634348227D-3,
     : .3695130194145505D-10,.2597481812334230D-9,.8225030584563125D-2,
     : .2549366221908178D-9,-.4656608638883828D-11,.3013404254699378D-2,
     : .3069490894028887D-10,.2659112928857773D-9,.4600694108605695D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 271, 280) /
     : .1567179077283956D-9,-.2605794626407036D-9, .4776654654564552D-2,
     : .3170147644918231D-9, .2014259746101557D-9, .5237785030215323D-2,
     : .2257945390031655D-9,-.1461737458796716D-9, .9885180158615642D-1,
     :-.1518893313638206D-9, .2356943194816912D-9, .4261275803689992D-2,
     : .7749267799033746D-11,.2472883412035945D-9, .1350038931288014D-2,
     : .2090960250427436D-9, .1221406675471295D-9, .7188097733552959D-2,
     :-.1176083529004488D-9,-.2610680632163292D-9, .5706478176044924D-2,
     : .5224945146665453D-10,.2592174936386246D-9, .2900628924171126D-1,
     :-.1924681127795483D-9,-.1569594178454833D-9, .2964858165211714D-2,
     : .2238662453793083D-9,-.1070180809124706D-9, .5386484869173622D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 281, 290) /
     : .1813607441412328D-9,-.1078426283067615D-9, .2453126837134502D-2,
     :-.1655863717623675D-9, .2297652539174931D-9, .3158262207672492D-2,
     : .2281175299076902D-9,-.1152367819982595D-9, .7515598625854425D-2,
     :-.1216940046270480D-9, .2453347812778936D-9, .2289921964575541D-2,
     :-.8697783145743145D-10,.1885717541598650D-9, .3559430801268914D-3,
     : .2046095114730716D-9,-.9565092262582874D-10,.7172595360830000D-2,
     : .1920844588930187D-10,.2523732253472135D-9, .4789536621270490D-2,
     :-.2406443670102340D-10,-.2182592669137236D-9,.8628063052980460D-2,
     : .6021410393713727D-10,.2005658339711116D-9, .1438780479627107D-1,
     : .2500787253347581D-9, .6699487230460294D-10,.2470425556733323D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 291, 300) /
     : .1562212111581197D-9, .1177530285475627D-9, .5717053118185848D-2,
     :-.1572634655078752D-9,-.1506601598902623D-9, .1041530990194771D-2,
     :-.1801740387835595D-9,-.8782446615610750D-10,.5201637544114728D-2,
     : .3075641138573326D-9,-.4004869590202472D-10,.2422325091264138D-2,
     : .1450002113825468D-9,-.1792032506622736D-09,.5285193869719679D-2,
     : .2388796539890357D-10,-.2025372779848161D-9,.2594657945064467D-2,
     : .1578314315051822D-9, .1864148504656809D-9, .2621038564570706D-2,
     : .1807927224909544D-9, .1113107791359084D-9, .7525873803516182D-2,
     : .1887589239357860D-9, .6432109062280920D-10,.1130056425534815D-1,
     :-.1691121237337397D-9,-.1842080336065264D-10,.3341374541768094D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 301, 310) /
     :-.5500315536064162D-10,-.2475297466148982D-9,.4522018418347999D-3,
     :-.2627896678982375D-10, .1846013911653434D-9,.1590231263109018D-2,
     : .4966660847244427D-10, .4539520991263396D-9,.2559470994186148D-2,
     :-.1787205887579925D-9, .1724021323963264D-10,.1276579343943480D-1,
     : .8966678075685010D-10,.1826055211311378D-9, .1819532854534074D-2,
     : .1103829203526473D-9, .1382686921693919D-9, .2055071724522644D-1,
     :-.8688678315943553D-10,-.1540496450750786D-9,.7106793432664234D-1,
     :-.1752183654065677D-9,-.2710489712068549D-10,.1008368807818559D-1,
     :-.6498064719196017D-10, .1694222263677307D-9,.2150113001507379D-2,
     : .1289358991522607D-9,-.1088146834924789D-9,.8612141388919285D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 311, 320) /
     :-.1716192884967800D-9, .1149036300334815D-10,.4219581877276982D-2,
     :-.1637804552778769D-9,-.4754072705112690D-10,.9148584640067238D-2,
     :-.1671147616649275D-9, .1689734435725062D-10,.7245302507095525D-2,
     :-.1731269711732283D-9,-.5878452718894764D-10,.1528800155648197D-3,
     :-.9607622058023272D-10,.1480702467188491D-09,.6441022231021957D-3,
     : .2394898768654204D-10,-.1722945492510900D-09,
     : .1770032179069948D-2,
     : .8901787214341677D-10,-.1827913712264271D-9,.3634869591463989D-3,
     : .1024393556321075D-9,-.1222860970862429D-9,.4645356500624915D-2,
     : .1598191327577733D-9,-.1060134795760276D-9,.2626899068489130D-2,
     :-.1448619490394545D-9,-.5411265903296263D-10,.4693326566897981D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 321, 330) /
     : .9028600140632994D-11,-.1670963435969118D-9,.5151635133219513D-2,
     : .9260866678223103D-10,-.1159749755341093D-9,.8039844937548632D-2,
     :-.2047516601557366D-9,-.2991735351049454D-11,.3090510439657102D-2,
     :-.1421023511257842D-9, .1010227516803402D-9,.1033544779337024D-2,
     : .8582426150610025D-10,.1356703745340739D-9,.1955985550407805D-2,
     :-.1382437965673692D-9,-.7052629449156111D-10,.3253327508928271D-3,
     :-.1408146156295631D-9,.2118914917853560D-10,.4367563580507380D-2,
     :-.1188656563034524D-9,-.1943269277268444D-9,.7834538150242741D-4,
     :-.1317143105087849D-9,-.6686009237156019D-10,.1862880656061546D-2,
     : .1518504777799346D-9, .1724519386578991D-10,.5295775465104817D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 331, 340) /
     :-.1235606549649313D-9,.6872427445624704D-10,.3650803555782104D-1,
     : .1088040395767444D-10,-.1456817564949223D-9,.1359761516759489D-2,
     :-.3705167842845575D-10,-.1726176631966594D-9,.4092894702023902D-3,
     :-.6740590279706981D-10,-.1612906368163395D-9,.2524728173203368D-2,
     : .2181953431767011D-10, .1407971170029688D-9,.3194965556494531D-2,
     :-.9099522706881555D-10, .1086371994057446D-9,.3147938970940117D-2,
     : .3334277679109816D-10,-.1455131205783315D-9,.2786383317347290D-2,
     : .1501145022342260D-9,-.4228124301861569D-10,.5464787425843424D-2,
     :-.1318489856844147D-9,-.3910449430248248D-10,.5932222059603951D-2,
     : .3169241103574413D-10,-.1301484460203829D-9,.9937317563657289D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 341, 350) /
     : .1204402431692628D-9, .6595056837133887D-10,.2495779214140109D-2,
     : .8711047540434062D-10,-.9722114174120940D-10,
     : .2809318888685244D-1,
     :-.8598392924030704D-10,-.1209752948726904D-9,.2834655364971810D-2,
     :-.1216634855024352D-9,.1800415033534551D-10,.2026446684218914D-3,
     :-.1400297001820493D-9,-.9909854119367429D-10,.5233886456354221D-2,
     :-.4189409264383327D-10,-.1129557074133668D-9,.5376600188003063D-2,
     :-.1374178887491889D-9, .1428115366076170D-10,.2682633962443435D-2,
     : .1010644680003317D-9, .7426977499194329D-10,.9910331335992908D-2,
     :-.3977881333641984D-10, .1177003525946826D-9,.8454774080579331D-2,
     : .4427023601863506D-10,-.1128922493914134D-9,.1176483139081743D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 351, 360) /
     :-.1281246068475336D-9,-.1762553654553775D-10,.2653691825392385D-2,
     : .1356591548719905D-9,-.5371476677292825D-10,.2332083626449874D-2,
     : .5440842904060571D-11,-.1248567553952963D-9,.1610037053492113D-1,
     :-.8087217131058631D-10,-.1111009138537168D-9,.5027177650452016D-2,
     :-.6630066248758572D-11, .1337874768346236D-9,.2612904309901623D-2,
     :-.6591327173141202D-10, .1013654930036978D-9,.1836310733440896D-2,
     : .8881700305432081D-10,.4400135073735271D-10,.7349103557898865D-3,
     :-.3335010948950924D-10,-.1167263138705900D-9,.2796740151121599D-2,
     :-.1028711705041118D-9,-.8338728975097938D-10,.2408992279305865D-2,
     : .1093435358099553D-9,-.7224465709984071D-10,.2202032203748129D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 361, 370) /
     :-.1554225426901496D-10,.1189165143402464D-9, .4922965281132179D-2,
     : .5255092588424515D-10,-.9998742094009271D-10,
     : .3301592722851034D-2,
     :-.1113060839182535D-9, .4340646505478133D-11,.6999060145091615D-2,
     :-.3695503519607810D-10,-.1176166367073767D-9,.2844042944297472D-2,
     : .8968060692677405D-10,-.5886678559174399D-10,
     : .1136621347609977D-1,
     :-.7911716280419079D-10,-.1031100622272740D-9,.2770759475190955D-2,
     :-.7765203496698973D-10,-.7715416416049791D-10,
     : .2875774899258664D-2,
     :-.3564571939301472D-10,-.1013576497063419D-9,.2226326601124418D-1,
     : .1003252874513503D-9,-.2560791754001882D-10,.3962349427122914D-3,
     : .4740732569886791D-10,-.9224049096834858D-10,
     : .3385845342704625D-1/
      DATA ((HFDATA(I,J),I=1,3),J= 371, 380) /
     : .1080688280001131D-9, .1363514073167100D-10,.7592483564413767D-1,
     :-.6348376104369870D-10,.8481594180696500D-10,.2182381404563435D-2,
     :-.4777449275375929D-10,.8736310735907676D-10,.2585321712518093D-2,
     : .4417055456359661D-10,-.9035727980163239D-10,
     : .3386753114681654D-1,
     :-.1675632827774342D-10,-.1168456417070512D-9,.1946834902554775D-3,
     :-.7891538145344769D-10,-.6246637380252875D-10,
     : .1504174140982712D-1,
     :-.7657838997208306D-10,-.6908191427460610D-10,
     : .5001018193696033D-2,
     :-.5338413551051561D-10,-.8642124147980398D-10,
     : .4558410700112101D-2,
     : .2412228377402460D-10,.9144351439714012D-10,.5649001319395650D-2,
     : .3542143605304634D-10,-.9311202259125409D-10,
     : .4277113447823431D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 381, 390) /
     : .8249126463704496D-10,.7030194053226824D-10,.1588269389629541D-3,
     :-.3345752132181988D-10,.9161111326711120D-10,.1580817633199320D-2,
     : .1339249957899950D-10,-.9430860654713632D-10,
     : .2226410996107371D-2,
     : .8397618901891211D-10,.4147516107597054D-10,.4461202518972018D-2,
     : .8162157813224211D-10,-.5145826967214506D-10,
     : .1043067100720903D-1,
     :-.9280899743355630D-10,-.9016398964404099D-12,
     : .3430986178997684D-2,
     : .5210539794964901D-10,-.7040240624680661D-10,
     : .4826812598668181D-2,
     : .4134773009509885D-10, .1133434048618565D-9,.4479967799258902D-3,
     : .8949963384485642D-10,-.5609761036405724D-11,
     : .1214027255250808D-2,
     :-.8679226504631198D-10,.4645422730694753D-11,.7258329232916247D-1/
      DATA ((HFDATA(I,J),I=1,3),J= 391, 400) /
     : .4546151595969439D-10,-.7423473631755157D-10,
     : .2236708023393244D-2,
     : .9293143615365297D-10,-.2159542854074585D-10,
     : .4919521577767681D-2,
     :-.7735418366422427D-10,-.2977199432691217D-10,
     : .5543698536896738D-2,
     : .7283840813605047D-10,.6393871676091920D-10,.2142564494341143D-2,
     :-.2981292703363827D-10,.7874046882539132D-10,.1427381302905792D0,
     : .5067243446864351D-10,.5601205741010145D-10,.5936848708573894D-3,
     :-.5242135890583344D-10,-.6472268255337759D-10,
     : .5252491938938575D-2,
     :-.9633648641458581D-10,-.3856860248178716D-10,
     : .2710013324491693D-2,
     :-.9004933162997287D-10,-.8111971987637559D-10,
     : .5442016864510958D-4,
     :-.6238713357515221D-10,.4926535847670085D-10,.1057936939914766D-1/
      DATA ((HFDATA(I,J),I=1,3),J= 401, 410) /
     :-.3587438154938241D-10,-.6304590978624653D-10,
     : .7501174628815481D-1,
     :-.3132035478871010D-10,.7622274350758718D-10,.5370381390512889D-2,
     : .6729891926716563D-11,-.7002503512455766D-10,
     : .6803570569457343D-1,
     :-.627744380523786D-11,-.8048220837549457D-10,.9187324429379473D-3,
     :-.3532806206302073D-10,-.6736131815989587D-10,
     : .3933876230472778D-1,
     : .6145024456505194D-10,-.7930624248683912D-10,
     : .3162319564164015D-2,
     :-.6619752912170018D-10,-.5216576256052480D-10,
     : .4694866115832703D-3,
     :-.3945208654379678D-10,.6004163120259647D-10,.1165000224468493D-1,
     :-.4960571497981702D-10,.6143294160090140D-10,.9673266770812759D-1,
     : .6993225830144011D-10,.3408509781223300D-10,.7395390815078665D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 411, 420) /
     :-.4188900507120225D-10,.6907851551674088D-10,.4772293461098947D-2,
     : .1984530996910037D-10,.6363924738858332D-10,.5070781300233840D-2,
     :-.5367287568546345D-10,.6938854975203991D-10,.1367632691531622D-2,
     :-.3604921866441162D-10,-.6128967969727557D-10,
     : .9736830855702811D-2,
     : .6579373649006054D-10,-.2606674801993823D-10,
     : .4086066157186787D-2,
     : .9913610005660354D-12,.8600538847065192D-10,.2037824404968359D-2,
     : .1590232996034163D-10,.6713656363852841D-10,.1725964676430689D-1,
     : .6642993775956527D-10,.1338512821037339D-10,.1149261872004163D-2,
     :-.2854273724326370D-10,.7100181501733721D-10,.1781291880259430D-1,
     :-.4587165025151134D-10,.4714558074351302D-10,.2811206464121644D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 421, 430) /
     : .3434610489760639D-10,-.6500385060191310D-10,
     : .1061340893778107D-1,
     :-.3381540329244925D-10,-.6159382451065694D-10,
     : .2925851444440280D-2,
     : .5868054807678789D-10,.4068780108789849D-10,.6045852265253143D-3,
     : .6472738525279102D-10,.5513266793846334D-10,.5229764278644139D-2,
     :-.7019072387730277D-10,.6464565090209841D-12,.2380721617420747D-2,
     :-.6203815509879805D-10,-.3488682856453980D-10,
     : .1301327803390666D-1,
     : .6483123249440968D-10,-.2253608860248839D-10,
     : .7199776824483447D-2,
     : .2395285290116872D-12,.6626099350196381D-10,.2397581559553534D-1,
     :-.5730218298833234D-10,-.2961062863297530D-10,
     : .4237098528298289D-1,
     : .4196121135749470D-10,.6028000214811027D-10,.5812993110218640D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 431, 440) /
     :-.6788373142659464D-10,.1352992918191805D-10,.1119245765495394D-1,
     : .6370215690409328D-10,-.2383644201560053D-10,
     : .1207345133290482D-1,
     : .8167665512887820D-11,-.6912330205924156D-10,
     : .4794277672248748D-2,
     :-.2099092399657215D-10,.6453168321084249D-10,.7747322419114643D-2,
     : .7071542139571026D-10,.1597237313410099D-10,.2974796029733572D-2,
     : .4372820437805604D-10,-.4398212715079903D-10,
     : .8281013402946119D-2,
     :-.6145785394765074D-10,.1927703560801032D-10,.7511727738915785D-2,
     : .6648066319557702D-10,-.3459794059838009D-10,
     : .2659956738233279D-2,
     : .4733480090003713D-10,.6168807594731659D-10,.6680750857115151D-3,
     :-.7081117247350449D-10,.1392535091690837D-10,.2528862635121164D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 441, 450) /
     :-.6138683080028946D-10,-.1070501347906173D-11,
     : .8180692745748801D-2,
     : .3864806561214937D-10,-.6640627747101357D-10,
     : .4437371962722612D-3,
     :-.4950447637005802D-10,-.3780761523974460D-10,.1330243141964640D0,
     :-.3600067107451092D-10,-.5064994423498266D-10,
     : .1724773207855091D-2,
     :-.1138478155134189D-10,-.5649622314635721D-10,
     : .7802990473210748D-3,
     : .4563264430025360D-10,-.3885797616807866D-10,
     : .9335775629659744D-2,
     : .5742936209651419D-10,.3090425773896948D-10,.3740618232289022D-3,
     :-.6174028194741818D-10,.3377462597242350D-11,.3914445636706444D-2,
     : .1998615326761373D-10,-.6899336511601725D-10,
     : .2294921198194185D-2,
     :-.2347535859828233D-10,.5601596788381541D-10,.1153934329999749D-1/
      DATA ((HFDATA(I,J),I=1,3),J= 451, 460) /
     :-.7637546761492737D-11,.6533027501436401D-10,.2055264079156410D-2,
     :-.3068859740464877D-11,.8827875536999970D-10,.5468371753946625D-2,
     : .7623193861401706D-10,-.4248372664249985D-10,
     : .2766850054715796D-2,
     :-.6768548703733000D-10,.1780876443886339D-10,.2435285867694598D-2,
     : .3650582815061193D-10,.4817511775556260D-10,.2089380399460345D-2,
     : .1765251034270316D-10,.6080198276423471D-10,.3385367004896391D-1,
     :-.4665792524496090D-10,.3304516036237143D-10,.1004200196625724D-2,
     :-.5704509351642615D-10,-.3312164302714652D-10,
     : .2214015117342180D-2,
     :-.3705786277829509D-11,.5467060581709537D-10,.1037087113595614D0,
     :-.1973754690501535D-10,.6111756186797655D-10,.7652255272119582D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 461, 470) /
     :-.4061041537495778D-10,-.4673660614612320D-10,
     : .4250027840166967D-3,
     : .3899090995937259D-10,.4454222063192314D-10,.5031482867314566D-2,
     : .3089045989653073D-10,.6613730743898923D-10,.1277133009691170D-3,
*  Mixed secular terms
     : .7727778643485643D-10,-.3569642677020368D-11,
     : .2521139512446695D-2,
     : .1826796312662946D-4, .1106683383572598D-4,.2737736388966212D-2,
     : .8414459909736863D-7, .6146439633520349D-7,.5475556880523133D-2,
     : .1068482888973241D-7, .5575610434643166D-8,.1686160317172538D-4,
     : .4391133853965492D-9, .2546359888706590D-7,.2283068300762698D-3,
     : .3616588999013463D-8, .1789677890472954D-8,.8213394359074665D-2,
     :-.1276527231760038D-8, .1093966119095913D-7,.3380709739354605D-3/
      DATA ((HFDATA(I,J),I=1,3),J= 471, 480) /
     : .7177191490198206D-8, .1220906132781699D-8,.4783374558389059D-2,
     : .1957563094198884D-8, .6918463996886943D-9,.2749068956280150D-2,
     :-.3095858436979942D-9, .4641455303692188D-9,.3153368978369206D-2,
     :-.4135168687195520D-9,-.5929955504767989D-10,.1025222715379577D-2,
     :-.3381693737071011D-9, .2040810169265410D-9,.1413106531097060D-3,
     : .2902455554025923D-9, .2296040681226013D-10,.1374619522895021D-2,
     :-.1607762392459389D-9,-.2403156810243311D-9,.2324275110041792D-2,
     : .5077338827110939D-12,-.3713596276791903D-9,.2264946618246240D-2,
     :-.5956947941184411D-10,.4373194454038897D-9,.2276226527217430D-2,
     :-.3758302606325317D-9,-.3625636861086191D-9,.2759367017789291D-2/
      DATA ((HFDATA(I,J),I=1,3),J= 481, 490) /
     : .2282084507106525D-9, .4285185079703540D-9,.2541736657062669D-2,
     : .8211160999937619D-10, .1366342675360493D-9,.5891489327022314D-2,
     : .3396989075222947D-9, -.3638353077748222D-9,.6988392539398318D-3,
     :-.6954853006266669D-10,-.1353018402038737D-9,.3256480775856626D-4,
     :-.8801421822856588D-10,.7246009966174998D-10,.4112474638227115D-2,
     :-.1157195532339339D-9, .4073397149404218D-9,.4168395174891270D-3,
     :-.4318728650724832D-10,.9558532111551671D-10,.4615545621144005D-3,
     :-.3104077028109024D-9, .7560192473927857D-11,.3075817659388770D-2,
     : .2388074688163559D-9,-.3377864064192275D-9, .7038513792416362D-3,
     :-.1288065550316744D-10, .1092759582484185D-9,.3112541369498863D-1/
      DATA ((HFDATA(I,J),I=1,3),J= 491, 500) /
     : .1026874330774251D-9,-.1993262156501514D-9,.2837131903717993D-3,
     :-.2466881331318127D-9,-.3292525226118399D-10,.3070757594877823D-2,
     :-.7023067065876671D-11,.8658407558150906D-10,.5203672159857556D-3,
     : .6742839439692457D-10, .1353884407060668D-9,.2428451549209403D-2,
     :-.5785505865371234D-10,-.1709407669863654D-10,
     : .2853388272606673D-2,
     : .1695453175831023D-9,-.8620687006463067D-10,.2361683295001627D-2,
     : .6848162785179664D-10,-.3892586521264537D-10,
     : .6162897315884004D-2,
     : .1035066407978821D-9,-.1665865298800093D-9,.2466336486376989D-2,
     :-.6813302911607002D-10,.2226675478633011D-10,.1108699635861177D-2,
     :-.3242068483345998D-10,-.3119591694482621D-10,
     : .3425118591597421D-2/

* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

      OFFSET = 0D0
      T_START = 2305450.5D0
      PI2 = 8D0*ATAN(1D0)
      CN1DT = 3D0*DBLE(N-1)
      CNDTI = 4D0/CN1DT

      T = (TJD-T_START) - 0.5D0*CN1DT
      PI2T = PI2*T
      XI = CNDTI*T
      S0 = (HFDATA(1,1)-OFFSET)+XI*(HFDATA(2,1)+HFDATA(3,1)*XI)

*  Fourier part
      S1 = 0D0
      DO I=1,NE
         J = NE+2-I
         ARG = PI2T*HFDATA(3,J)
         S1 = S1 + (HFDATA(1,J)*DSIN(ARG)+HFDATA(2,J)*DCOS(ARG))
      END DO

*  Mixed secular part
      S2=0D0
      DO I=1,NX
         J = NE+NX+2-I
         ARG = PI2T*HFDATA(3,J)
         S2 = S2 + XI*(HFDATA(1,J)*DSIN(ARG)+HFDATA(2,J)*DCOS(ARG))
      ENDDO
      HF2002=(S2+S1)+S0

*  Linear term contribution added
      HF2002_IERS = HF2002/(1D0-LB) + C4TERMS*(TJD-TT0)*86400D0

* Finished.

*+----------------------------------------------------------------------
*
*  Copyright (C) 2008
*  IERS Conventions Center
*
*  ==================================
*  IERS Conventions Software License
*  ==================================
*
*  NOTICE TO USER:
*
*  BY USING THIS SOFTWARE YOU ACCEPT THE FOLLOWING TERMS AND CONDITIONS
*  WHICH APPLY TO ITS USE.
*
*  1. The Software is provided by the IERS Conventions Center ("the
*     Center").
*
*  2. Permission is granted to anyone to use the Software for any
*     purpose, including commercial applications, free of charge,
*     subject to the conditions and restrictions listed below.
*
*  3. You (the user) may adapt the Software and its algorithms for your
*     own purposes and you may distribute the resulting "derived work"
*     to others, provided that the derived work complies with the
*     following requirements:
*
*     a) Your work shall be clearly identified so that it cannot be
*        mistaken for IERS Conventions software and that it has been
*        neither distributed by nor endorsed by the Center.
*
*     b) Your work (including source code) must contain descriptions of
*        how the derived work is based upon and/or differs from the
*        original Software.
*
*     c) The name(s) of all modified routine(s) that you distribute
*        shall be changed.
*
*     d) The origin of the IERS Conventions components of your derived
*        work must not be misrepresented; you must not claim that you
*        wrote the original Software.
*
*     e) The source code must be included for all routine(s) that you
*        distribute.  This notice must be reproduced intact in any
*        source distribution.
*
*  4. In any published work produced by the user and which includes
*     results achieved by using the Software, you shall acknowledge
*     that the Software was used in obtaining those results.
*
*  5. The Software is provided to the user "as is" and the Center makes
*     no warranty as to its use or performance.   The Center does not
*     and cannot warrant the performance or results which the user may
*     obtain by using the Software.  The Center makes no warranties,
*     express or implied, as to non-infringement of third party rights,
*     merchantability, or fitness for any particular purpose.  In no
*     event will the Center be liable to the user for any consequential,
*     incidental, or special damages, including any lost profits or lost
*     savings, even if a Center representative has been advised of such
*     damages, or for any claim by any third party.
*
*  Correspondence concerning IERS Conventions software should be
*  addressed as follows:
*
*                     Gerard Petit
*     Internet email: gpetit[at]bipm.org
*     Postal address: IERS Conventions Center
*                     Time, frequency and gravimetry section, BIPM
*                     Pavillon de Breteuil
*                     92312 Sevres  FRANCE
*
*     or
*
*                     Brian Luzum
*     Internet email: brian.luzum[at]usno.navy.mil
*     Postal address: IERS Conventions Center
*                     Earth Orientation Department
*                     3450 Massachusetts Ave, NW
*                     Washington, DC 20392
*
*
*-----------------------------------------------------------------------
      END
